================
GitHub Utils API
================

What is it?
___________
This package is used to provide a **simple** python interface for interacting with GitHub.
It is based on the official public Rest API documentation and private methods discovered by the community.

This project is documented at https://githubutilsapi.readthedocs.io/

How to Install?
_______________

From PyPI

.. code-block:: console

   $ pip install github-utils-api

From Source

- Git clone repository
- Use :code:`pip install -r requirements.txt` to install the required packages
- or :code:`pipenv install && pipenv install --dev`

How to use?
___________
Import this python package and code.

.. code-block:: python

   from github_utils_api import GitHub

How to contribute?
__________________
First of all, I am happy for any PR requests.
Let's fork and provide your changes :)
 1. Fork this project
 2. Install required software Python3
 3. Make your changes
 4. Remeber to generate documented methods
 5. Test your changes and create the pull request

License
_______
This project is licensed under the terms of the MIT license.

For a copy, see <https://opensource.org/licenses/MIT>.
